#!/bin/sh
#
# Sets up the loadpng package for building with the specified compiler.
#

proc_help()
{
   echo
   echo "Usage: $0 <platform> [--quick|--dtou|--utod]"
   echo
   echo "Where platform is one of: djgpp, mingw32, unix"
   echo "The --quick parameter turns off text file conversion, --dtou converts from"
   echo "DOS/Win32 format to Unix, --utod converts from Unix to DOS/Win32 format."
   echo "If no parameter is specified --quick is assumed."
   echo

   AL_NOCONV="1"
}

proc_fix()
{
   echo "Configuring loadpng for $1 ..."

   echo "# generated by fix.sh" > Makefile
   echo "MAKEFILE_INC=$2"      >> Makefile
   echo "include Makefile.all" >> Makefile
}

proc_filelist()
{
   # common files.
   AL_FILELIST=`find . -type f "(" ! -path "*/.*" ")" -a "(" \
      -name "*.c" -o -name "*.cfg" -o -name "*.cpp" -o -name "*.def" -o \
      -name "*.h" -o -name "*.hin" -o -name "*.in" -o -name "*.inc" -o \
      -name "*.m" -o -name "*.m4" -o -name "*.mft" -o -name "*.s" -o \
      -name "*.rc" -o -name "*.rh" -o -name "*.spec" -o -name "*.pl" -o \
      -name "*.txt" -o -name "*._tx" -o -name "Makefile*" -o \
      -name "*.inl" -o -name "configure" -o -name "CHANGES" -o \
      -name "AUTHORS" -o -name "THANKS" ")" \
   `

   # touch unix shell scripts?
   if [ "$1" != "omit_sh" ]; then
      AL_FILELIST="$AL_FILELIST `find . -type f -name '*.sh'`"
   fi

   # touch DOS batch files?
   if [ "$1" != "omit_bat" ]; then
      AL_FILELIST="$AL_FILELIST `find . -type f -name '*.bat'`"
   fi
}

proc_utod()
{
   echo "Converting files from Unix to DOS/Win32 ..."
   proc_filelist "omit_sh"
   for file in $AL_FILELIST; do
      if [ "$ALLEGRO_USE_CYGWIN" = "1" ]; then
         unix2dos "$file"
      else
         echo "$file"
         perl -p -e "s/([^\r]|^)\n/\1\r\n/" "$file" > _tmpfile
         touch -r "$file" _tmpfile
         mv _tmpfile "$file"
      fi
   done
}

proc_dtou()
{
   echo "Converting files from DOS/Win32 to Unix ..."
   proc_filelist "omit_bat"
   for file in $AL_FILELIST; do
      if [ "$ALLEGRO_USE_CYGWIN" = "1" ]; then
         dos2unix "$file"
      else
         echo "$file"
         mv "$file" _tmpfile
         tr -d '\015' < _tmpfile > "$file"
         touch -r _tmpfile "$file"
         rm _tmpfile
      fi
   done
   chmod +x *.sh
   if [ -f configure ]; then
      chmod +x configure
   fi
}

# prepare loadpng for the given platform.

if [ -z "$1" ]; then
   proc_help
   exit 0
fi

case "$1" in
   "djgpp"   ) proc_fix "DOS (djgpp)"       "Makefile.dj";;
   "mingw"   ) proc_fix "Windows (MinGW)"   "Makefile.mgw";;
   "mingw32" ) proc_fix "Windows (MinGW)"   "Makefile.mgw";;
   "unix"    ) proc_fix "Unix"              "Makefile.unx";;
   "help"    ) proc_help;;
   *         ) echo "Platform not supported by loadpng." ;;
esac

# convert all text-file line endings.

if [ "$AL_NOCONV" != "1" ]; then
   case "$2" in
      "--utod"  ) proc_utod "$1";;
      "--dtou"  ) proc_dtou "$1";;
   esac
fi

